.. meta::
   :description:
        marshmallow is an ORM/ODM/framework-agnostic library for converting complex datatypes, such as objects, to and from native Python datatypes.

***********
marshmallow
***********

*Object serialization and deserialization, lightweight and fluffy.*

Release v\ |version|. (:doc:`changelog`)

----

.. include:: ../README.rst
    :start-after: .. start elevator-pitch
    :end-before: .. end elevator-pitch

Ready to get started? Go on to the :doc:`quickstart` or check out some :doc:`examples <examples/index>`.

Upgrading from an older version?
================================

See the :doc:`upgrading` page for notes on getting your code up-to-date with the latest version.

Why another library?
=====================

See :doc:`this document <why>` to learn about what makes marshmallow unique.

Sponsors
========

.. include:: ../README.rst
    :start-after: .. start sponsors
    :end-before: .. end sponsors

.. toctree::
    :maxdepth: 1
    :hidden:
    :titlesonly:

    Home <self>

Usage guide
===========

.. toctree::
    :caption: Usage guide
    :maxdepth: 2

    install
    quickstart
    nesting
    custom_fields
    extending/index
    examples/index


API reference
=============

.. toctree::
    :caption: API reference
    :maxdepth: 1

    api_reference

Project info
=============

.. toctree::
    :caption: Project info
    :maxdepth: 1

    why
    changelog
    upgrading
    whos_using
    license
    authors
    contributing
    code_of_conduct
    kudos
    donate

.. toctree::
    :hidden:
    :caption: Useful links

    marshmallow @ PyPI <https://pypi.org/project/marshmallow/>
    marshmallow @ GitHub <https://github.com/marshmallow-code/marshmallow/>
    Issue Tracker <https://github.com/marshmallow-code/marshmallow/issues>
    Ecosystem <https://github.com/marshmallow-code/marshmallow/wiki/Ecosystem>
